==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/dd/dd49beb9d94046e738044ff86a86155a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php */
class __TwigTemplate_52a9ab50f241baca8cd5e23c55b35071 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CacheBundle\\Cache\\Adapter;

use Mautic\\CacheBundle\\Exceptions\\InvalidArgumentException;
use Mautic\\CoreBundle\\Helper\\PRedisConnectionHelper;
use Symfony\\Component\\Cache\\Adapter\\RedisAdapter;
use Symfony\\Component\\Cache\\Adapter\\TagAwareAdapter;

class RedisTagAwareAdapter extends TagAwareAdapter
{
    public function __construct(array \$servers, string \$namespace, int \$lifetime, bool \$primaryOnly)
    {
        if (!isset(\$servers['dsn'])) {
            throw new InvalidArgumentException('Invalid redis configuration. No server specified.');
        }

        \$options = array_key_exists('options', \$servers) ? \$servers['options'] : [];

        \$options['primaryOnly'] = \$primaryOnly;

        \$client = PRedisConnectionHelper::createClient(PRedisConnectionHelper::getRedisEndpoints(\$servers['dsn']), \$options);

        parent::__construct(
            new RedisAdapter(\$client, \$namespace, \$lifetime),
            new RedisAdapter(\$client, \$namespace.'.tags.', \$lifetime)
        );
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php", "/var/www/mautic-ktn/app/bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/dd/dd49beb9d94046e738044ff86a86155a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php */
class __TwigTemplate_52a9ab50f241baca8cd5e23c55b35071 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CacheBundle\\Cache\\Adapter;

use Mautic\\CacheBundle\\Exceptions\\InvalidArgumentException;
use Mautic\\CoreBundle\\Helper\\PRedisConnectionHelper;
use Symfony\\Component\\Cache\\Adapter\\RedisAdapter;
use Symfony\\Component\\Cache\\Adapter\\TagAwareAdapter;

class RedisTagAwareAdapter extends TagAwareAdapter
{
    public function __construct(array \$servers, string \$namespace, int \$lifetime, bool \$primaryOnly)
    {
        if (!isset(\$servers['dsn'])) {
            throw new InvalidArgumentException('Invalid redis configuration. No server specified.');
        }

        \$options = array_key_exists('options', \$servers) ? \$servers['options'] : [];

        \$options['primaryOnly'] = \$primaryOnly;

        \$client = PRedisConnectionHelper::createClient(PRedisConnectionHelper::getRedisEndpoints(\$servers['dsn']), \$options);

        parent::__construct(
            new RedisAdapter(\$client, \$namespace, \$lifetime),
            new RedisAdapter(\$client, \$namespace.'.tags.', \$lifetime)
        );
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php", "/var/www/html/mauticGIT-Test/app/bundles/CacheBundle/Cache/Adapter/RedisTagAwareAdapter.php");
    }
}
